<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\RekamMedis;
use App\Models\Pasien;
use App\Models\KategoriObat;
use App\Models\Obat;
use App\Models\Dokter;
use App\Models\DokterRekamMedis;
use App\Models\ObatRekamMedis;
use App\Models\Profil;

class RekamMedisController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(!\Helper::hakAkses('Rekam Medis','View')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $title = "Rekam Medis";
        $url = "rekam_medis";
        $menu = "Rekam Medis";

        $rekam_medis = RekamMedis::orderBy('created_at', 'DESC')->get();
        return view('rekam_medis.index', compact('title', 'url', 'menu', 'rekam_medis'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!\Helper::hakAkses('Rekam Medis','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        $title = "Rekam Medis";
        $url = "rekam_medis";
        $menu = "Rekam Medis";

        $pasiens = Pasien::all();
        $kategori = KategoriObat::all();
        $dokters = Dokter::all();

        return view('rekam_medis.create', compact('title', 'url', 'menu', 'pasiens', 'kategori', 'dokters'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(!\Helper::hakAkses('Rekam Medis','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $this->validate($request, [
            'nomor_rekam_medis' => 'required',
            'tgl_periksa' => 'required',
            'pasien_id' => 'required',
            'dokter_utama' => 'required',
            'obat_id' => 'required',
            'jumlah' => 'required',
            'total' => 'required',
            'harga' => 'required',
            'diskon' => 'required',
        ]);

        try {
            $rekam_medis = RekamMedis::create([
                'nomor_rekam_medis' => $request->nomor_rekam_medis,
                'pasien_id' => $request->pasien_id,
                'keluhan' => $request->keluhan,
                'diagnosa' => $request->diagnosa,
                'penanganan' => $request->penanganan,
                'tgl_periksa' => $request->tgl_periksa,
                'total' => $request->total,
                'diskon' => $request->diskon,
            ]);

            $dokter_utama = DokterRekamMedis::create([
                'rekam_medis_id' => $rekam_medis->id,
                'dokter_id' => $request->dokter_utama,
                'jenis_terapis' => "Utama",
            ]);

            if($request->asisten){
                for ($i=0; $i < count($request->asisten); $i++) { 
                    $dokter = DokterRekamMedis::create([
                        'rekam_medis_id' => $rekam_medis->id,
                        'dokter_id' => $request->asisten[$i],
                        'jenis_terapis' => "Asisten",
                    ]);
                }
            }

            for ($i=0; $i < count($request->obat_id); $i++) { 
                // $findHargaObat = Obat::find($request->obat_id)->first()->harga;
                $obat = ObatRekamMedis::create([
                    'rekam_medis_id' => $rekam_medis->id,
                    'obat_id' => $request->obat_id[$i],
                    'jumlah' => $request->jumlah[$i],
                    'harga' => $request->harga[$i],
                ]);
            }

            \Helper::addUserLog('menambah data Rekam Medis '.$request->nama_rekam_medis,$rekam_medis->toArray());

            return redirect()->route('rekam_medis.index')->with('success', 'Data Berhasil Ditambahkan');

        } catch (\Throwable $th) {
            if (@$rekam_medis) {
                $rekam_medis->delete();
            }
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(!\Helper::hakAkses('Rekam Medis','View')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $title = "Rekam Medis";
        $url = "rekam_medis";
        $menu = "Rekam Medis";

        $data = RekamMedis::find($id);
        return view('rekam_medis.show', compact('title', 'url', 'menu', 'data'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(!\Helper::hakAkses('Rekam Medis','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $rekam_medis = RekamMedis::find($id);
        $asisten = Dokter::whereHas('rekamMedis', function($rm) use($id){
            $rm->where('jenis_terapis', 'Asisten')->where('rekam_medis_id',$id);
        })->pluck('id')->toArray();
        
        $title = "Rekam Medis";
        $url = "rekam_medis";
        $menu = "Rekam Medis";

        $pasiens = Pasien::all();
        $obats = Obat::all();
        $dokters = Dokter::all();
        
        return view('rekam_medis.edit', compact('title', 'url', 'menu', 'rekam_medis', 'pasiens', 'obats', 'dokters', 'asisten'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(!\Helper::hakAkses('Rekam Medis','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        $this->validate($request, [
            'nomor_rekam_medis' => 'required',
            'tgl_periksa' => 'required',
            'pasien_id' => 'required',
            'dokter_id' => 'required',
            'obat_id' => 'required',
            'jumlah' => 'required',
            'total' => 'required',
            'harga' => 'required',
            'diskon' => 'required',
        ]);
        
        try {
            $rekam_medis = RekamMedis::find($id);
            $rekam_medis->update([
                'nomor_rekam_medis' => $request->nomor_rekam_medis,
                'pasien_id' => $request->pasien_id,
                'keluhan' => $request->keluhan,
                'diagnosa' => $request->diagnosa,
                'penanganan' => $request->penanganan,
                'tgl_periksa' => $request->tgl_periksa,
                'total' => $request->total,
                'diskon' => $request->diskon,
            ]);
            
            $rekam_medis->dokterRm()->delete();
            $dokter_utama = DokterRekamMedis::create([
                'rekam_medis_id' => $rekam_medis->id,
                'dokter_id' => $request->dokter_id,
                'jenis_terapis' => "Utama",
            ]);

            if($request->asisten){
                for ($i=0; $i < count($request->asisten); $i++) { 
                    $dokter = DokterRekamMedis::create([
                        'rekam_medis_id' => $rekam_medis->id,
                        'dokter_id' => $request->asisten[$i],
                        'jenis_terapis' => "Asisten",
                    ]);
                }
            }

            $rekam_medis->obatRm()->delete();
            for ($i=0; $i < count($request->obat_id); $i++) { 
                // $findHargaObat = Obat::find($request->obat_id)->first()->harga;
                $obat = ObatRekamMedis::create([
                    'rekam_medis_id' => $rekam_medis->id,
                    'obat_id' => $request->obat_id[$i],
                    'jumlah' => $request->jumlah[$i],
                    'harga' => $request->harga[$i],
                ]);
            }

            \Helper::addUserLog('Mengubah data Rekam Medis '.$request->nama_rekam_medis,$rekam_medis->toArray());

            return redirect()->route('rekam_medis.index')->with('success', 'Data Berhasil Diubah');

        } catch (\Throwable $th) {
            // if (@$rekam_medis) {
            //     $rekam_medis->delete();
            // }
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(!\Helper::hakAkses('Rekam Medis','Delete')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {    
            $rekam_medis = RekamMedis::find($id);            
            $nama = $rekam_medis->nama_rekam_medis;
            $rekam_medis->delete();
            \Helper::addUserLog('Menghapus Data Rekam Medis '.$nama,$rekam_medis->toArray());        
           
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

        return redirect(route('rekam_medis.index'))->with('success', 'Data Berhasil Dihapus');
    }

    public function print($id)
    {
        if(!\Helper::hakAkses('Rekam Medis','View')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $title = "Rekam Medis";
        $url = "rekam_medis";
        $menu = "Rekam Medis";

        $data = RekamMedis::find($id);
        $profil = Profil::first();
        return view('rekam_medis.print', compact('title', 'url', 'menu', 'data', 'profil'));
    }
}
